==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/OperationMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.OperationMessage;
import io.ciera.tool.sql.ooaofooa.message.OperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;

import java.util.Arrays;
import java.util.List;


public class OperationMessageSetImpl extends InstanceSet<OperationMessageSet,OperationMessage> implements OperationMessageSet {

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( OperationMessage operationmessage : this ) operationmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( OperationMessage operationmessage : this ) operationmessage.setTfr_ID( ref_Tfr_ID );
    }


    // selections
    @Override
    public O_TFRSet R1011_is_invocation_of_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( OperationMessage operationmessage : this ) o_tfrset.add( operationmessage.R1011_is_invocation_of_O_TFR() );
        return o_tfrset;
    }
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( OperationMessage operationmessage : this ) synchronousmessageset.add( operationmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public OperationMessage nullElement() {
        return OperationMessageImpl.EMPTY_OPERATIONMESSAGE;
    }

    @Override
    public OperationMessageSet emptySet() {
      return new OperationMessageSetImpl();
    }

    @Override
    public OperationMessageSet value() {
        return this;
    }

    @Override
    public List<OperationMessage> elements() {
        return Arrays.asList(toArray(new OperationMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/OperationMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.OperationMessage;
import io.ciera.tool.sql.ooaofooa.message.OperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class OperationMessageSetImpl extends InstanceSet<OperationMessageSet,OperationMessage> implements OperationMessageSet {

    public OperationMessageSetImpl() {
    }

    public OperationMessageSetImpl(Comparator<? super OperationMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( OperationMessage operationmessage : this ) operationmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( OperationMessage operationmessage : this ) operationmessage.setTfr_ID( ref_Tfr_ID );
    }


    // selections
    @Override
    public O_TFRSet R1011_is_invocation_of_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( OperationMessage operationmessage : this ) o_tfrset.add( operationmessage.R1011_is_invocation_of_O_TFR() );
        return o_tfrset;
    }
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( OperationMessage operationmessage : this ) synchronousmessageset.add( operationmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public OperationMessage nullElement() {
        return OperationMessageImpl.EMPTY_OPERATIONMESSAGE;
    }

    @Override
    public OperationMessageSet emptySet() {
      return new OperationMessageSetImpl();
    }

    @Override
    public OperationMessageSet emptySet(Comparator<? super OperationMessage> comp) {
      return new OperationMessageSetImpl(comp);
    }

    @Override
    public OperationMessageSet value() {
        return this;
    }

    @Override
    public List<OperationMessage> elements() {
        return Arrays.asList(toArray(new OperationMessage[0]));
    }

}
